@@ -135,6 +135,26 @@ class Targets(Plugin):
             if res.status_code == 200:
                 return res.json()
 
+    def get_query(self, status='registered', query_changes={}):
+        """Get information about targets returned from a query"""
+        if not self.db.categories:
+            self.get_assessments()
+        categories = []
+        for category in self.db.categories:
+            if category.passed_practical and category.passed_written:
+                categories.append(category.id)
+        query = {
+            'filter[primary]': status,
+            'filter[secondary]': 'all',
+            'filter[industry]': 'all',
+            'filter[category][]': categories
+        }
+        query.update(query_changes)
+        res = self.api.request('GET', 'targets', query=query)
+        if res.status_code == 200:
+            self.db.add_targets(res.json(), is_registered=True)
+            return res.json()
+
     def get_registered_summary(self):
         """Get information on your registered targets"""
         res = self.api.request('GET', 'targets/registered_summary')
@@ -161,7 +181,7 @@ class Targets(Plugin):
                 categories[category.id] = category.name
             if categories[target.category].lower() == 'host':
                 return self.get_scope_host(target)
-            elif categories[target.category].lower() == 'web application':
+            elif categories[target.category].lower() in ['web application', 'mobile']:
                 return self.get_scope_web(target)
 
     def get_scope_host(self, target=None, **kwargs):
@@ -180,7 +200,7 @@ class Targets(Plugin):
                 return scope
 
     def get_scope_web(self, target=None, **kwargs):
-        """Get the scope of a Web target"""
+        """Get the web scpope of a Web or Mobile target"""
         if target is None:
             target = self.db.find_targets(**kwargs)
             if target:
@@ -199,25 +219,15 @@ class Targets(Plugin):
 
     def get_unregistered(self):
         """Get slugs of all unregistered targets"""
-        if not self.db.categories:
-            self.get_assessments()
-        categories = []
-        for c in self.db.categories:
-            if c.passed_practical and c.passed_practical:
-                categories.append(c.id)
-        query = {
-                'filter[primary]': 'unregistered',
-                'filter[secondary]': 'all',
-                'filter[industry]': 'all',
-                'filter[category][]': categories
+        return self.get_query(status='unregistered')
+
+    def get_upcoming(self):
+        """Get slugs and upcoming start dates of all upcoming targets"""
+        query_changes = {
+            'sorting[field]': 'upcomingStartDate',
+            'sorting[direction]': 'asc'
         }
-        res = self.api.request('GET', 'targets', query=query)
-        ret = []
-        if res.status_code == 200:
-            self.db.add_targets(res.json(), is_registered=True)
-            for t in res.json():
-                ret.append({'codename': t['codename'], 'slug': t['slug']})
-        return ret
+        return self.get_query(status='upcoming', query_changes=query_changes)
 
     def set_connected(self, target=None, **kwargs):
         """Connect to a target"""
